@@ -1,4 +1,4 @@
-/*  Misfit Model 3D
+/*  Maverick Model 3D
  * 
  *  Copyright (c) 2004-2007 Kevin Worcester
  * 
@@ -35,7 +35,7 @@
 #include <list>
 #include <map>
 #include <QtCore/QObject>
-#include <QtGui/QApplication>
+#include <QtWidgets/QApplication>
 
 using std::list;
 using std::map;
@@ -60,12 +60,12 @@ bool WeldCommand::activated( int arg, Model * model )
          int unwelded = 0;
          int welded = 0;
          weldSelectedVertices( model, 0.0001, unwelded, welded );
-         model_status( model, StatusNormal, STATUSTIME_SHORT, (qApp->translate( "Command", "Welded %1 vertices into %2 vertices" ).arg(unwelded).arg(welded)).toUtf8() );
+         model_status( model, StatusNormal, STATUSTIME_SHORT, "%s", (qApp->translate( "Command", "Welded %1 vertices into %2 vertices" ).arg(unwelded).arg(welded)).toUtf8().data() );
          return true;
       }
       else
       {
-         model_status( model, StatusError, STATUSTIME_LONG, qApp->translate( "Command", "You must have 2 or more vertices selected to weld." ).toUtf8() );
+         model_status( model, StatusError, STATUSTIME_LONG, "%s", qApp->translate( "Command", "You must have 2 or more vertices selected to weld." ).toUtf8().data() );
       }
    }
    
