@@ -1,4 +1,4 @@
-/*  Misfit Model 3D
+/*  Maverick Model 3D
  * 
  *  Copyright (c) 2004-2007 Kevin Worcester
  * 
@@ -24,7 +24,7 @@
 #ifndef __TEXFRAME_H
 #define __TEXFRAME_H
 
-#include <QtGui/QFrame>
+#include <QtWidgets/QFrame>
 #include <QtGui/QResizeEvent>
 
 class Model;
