@@ -24,10 +24,13 @@
 #include "animsetwin.h"
 
 #include "animconvertwin.h"
+#include "animeditwin.h"
 #include "decalmgr.h"
 #include "log.h"
 #include "msg.h"
+#include "3dmprefs.h"
 #include "helpwin.h"
+#include "newanim.h"
 
 #include <QtWidgets/QPushButton>
 #include <QtWidgets/QComboBox>
@@ -73,7 +76,6 @@ AnimSetWindow::AnimSetWindow( Model * model, QWidget * parent )
       m_animType->setCurrentIndex(0);
    }
 
-   fillAnimationList();
    animModeSelected( m_animType->currentIndex() );
 
    //Model::AnimationModeE mode = indexToMode( m_animType->currentIndex() );
@@ -241,19 +243,49 @@ void AnimSetWindow::downClicked()
 
 void AnimSetWindow::newClicked()
 {
-   bool ok = false;
-
-   QString name = QInputDialog::getText( this,
-         tr( "New Animation" ),
-         tr( "New name:" ),
-         QLineEdit::Normal, QString(""), &ok );
-
-   if ( ok && !name.isEmpty() )
+   NewAnim win( this );
+   g_prefs.setDefault( "ui_new_anim_type", 0 );
+   win.setSkeletal( g_prefs( "ui_new_anim_type" ).intValue() == 0 );
+   if ( win.exec() )
    {
-      int num = m_model->addAnimation( indexToMode( m_animType->currentIndex() ), name.toUtf8() );
+      g_prefs( "ui_new_anim_type" ) = win.isSkeletal() ? 0 : 1;
+      QString name = win.getAnimName();
+      Model::AnimationModeE mode = win.isSkeletal()
+         ? Model::ANIMMODE_SKELETAL
+         : Model::ANIMMODE_FRAME;
+      unsigned frameCount = win.getAnimFrameCount();
+      double fps = win.getAnimFPS();
+      bool loop = win.getAnimLooping();
+
+      int anim = m_model->addAnimation( mode, name.toUtf8() );
+      m_model->setAnimFrameCount( mode, anim, frameCount );
+      m_model->setAnimFPS( mode, anim, fps );
+      m_model->setAnimLooping( mode, anim, loop );
+      m_model->setCurrentAnimation( mode, anim );
+
+      if ( mode == Model::ANIMMODE_SKELETAL )
+      {
+         m_animType->setCurrentIndex(0);
+      }
+      else if ( mode == Model::ANIMMODE_FRAME )
+      {
+         m_animType->setCurrentIndex(1);
+      }
+      else if ( mode == Model::ANIMMODE_FRAMERELATIVE )
+      {
+         m_animType->setCurrentIndex(2);
+      }
+      else
+      {
+         m_animType->setCurrentIndex(0);
+      }
+
+      animModeSelected( m_animType->currentIndex() );
+
+      int num = m_animList->count() - 1;
+
       if ( num >= 0 )
       {
-         m_animList->insertItem( num, name );
          m_animList->setCurrentItem(m_animList->item(num));
 
          m_animList->clearSelection();
@@ -262,42 +294,41 @@ void AnimSetWindow::newClicked()
    }
 }
 
-void AnimSetWindow::renameClicked()
+void AnimSetWindow::editClicked()
 {
-   bool isSelection = false;
-   unsigned firstSelection = 0;
-
+   Model::AnimationModeE mode = indexToMode( m_animType->currentIndex() );
    unsigned count = m_animList->count();
-   for ( firstSelection = 0; firstSelection < count; firstSelection++ )
+   std::list<unsigned> animIndicies;
+
+   for ( unsigned t = 0; t < count; t++ )
    {
-      if ( m_animList->item(firstSelection)->isSelected() )
+      if ( m_animList->item(t)->isSelected() )
       {
-         isSelection = true;
-         break;
+         animIndicies.push_back( t );
       }
    }
 
-   if ( isSelection )
+   AnimEditWindow aew( this );
+
+   aew.setAnimationData( m_model, mode, animIndicies );
+   aew.exec();
+
+   if ( !animIndicies.empty() )
    {
-      bool ok = false;
+      fillAnimationList();
 
-      QString name = QInputDialog::getText( this,
-            tr( "Rename Animation" ),
-            tr( "New name:" ),
-            QLineEdit::Normal, m_animList->item( firstSelection )->text(), &ok );
+      list<unsigned>::iterator it;
 
-      if ( ok && !name.isEmpty() )
+      m_animList->setCurrentItem(m_animList->item(animIndicies.back()));
+
+      count = m_animList->count();
+      for ( unsigned int t = 0; t < count; ++t )
       {
-         Model::AnimationModeE mode = indexToMode( m_animType->currentIndex() );
-
-         for ( unsigned t = 0; t < count; t++ )
-         {
-            if ( m_animList->item(t)->isSelected() )
-            {
-               m_model->setAnimName( mode, t, name.toUtf8() );
-               m_animList->item(t)->setText( name );
-            }
-         }
+         m_animList->item(t)->setSelected( false );
+      }
+      for ( it = animIndicies.begin(); it != animIndicies.end(); it++ )
+      {
+         m_animList->item( *it )->setSelected( true );
       }
    }
 }
