@@ -88,12 +88,17 @@ AnimWidget::AnimWidget( Model * model, bool isUndo, QWidget * parent )
      m_model( model ),
      m_playing( false ),
      m_undoing( isUndo ),
-     m_ignoreChange( false ),
-     m_changeFrameFocused( false ),
-     m_changeFrameDeferred( false )
+     m_ignoreChange( false )
 {
    setupUi( this );
 
+   // Don't allow text editing in the frame count QSpinBox. It updates
+   // the frame count immediately. 9 -> 10 will truncate to 1 frame and
+   // then add empty frames.
+   QLineEdit *lineEdit = m_frameCount->findChild<QLineEdit*>();
+   lineEdit->setReadOnly( true );
+   lineEdit->setFocusPolicy( Qt::NoFocus );
+
    log_debug( "AnimWidget constructor\n" );
 
    m_animTimer = new QTimer( this );
@@ -161,17 +166,22 @@ void AnimWidget::initialize( Model * model, bool isUndo )
    }
    else
    {
+      m_currentAnim = 0;
+      m_currentFrame = 0;
       m_mode = Model::ANIMMODE_SKELETAL;
+
       if ( m_skelAnimCount > 0 )
       {
-         m_model->setCurrentAnimation( m_mode, indexToAnim( m_animName->currentIndex() ) );
+         m_currentAnim = indexToAnim( m_animName->currentIndex() );
+         m_model->setCurrentAnimation( m_mode, m_currentAnim );
       }
       else if ( m_frameAnimCount > 0 )
       {
          m_mode = Model::ANIMMODE_FRAME;
-         m_model->setCurrentAnimation( m_mode, indexToAnim( m_animName->currentIndex() ) );
+         m_currentAnim = indexToAnim( m_animName->currentIndex() );
+         m_model->setCurrentAnimation( m_mode, m_currentAnim );
       }
-      m_model->setCurrentAnimationFrame( 0 );
+      m_model->setCurrentAnimationFrame( m_currentFrame );
 
       refreshPage();
 
@@ -199,8 +209,14 @@ void AnimWidget::nameSelected( int index )
          Model::AnimationModeE mode = win.isSkeletal() 
             ? Model::ANIMMODE_SKELETAL
             : Model::ANIMMODE_FRAME;
+         unsigned frameCount = win.getAnimFrameCount();
+         double fps = win.getAnimFPS();
+         bool loop = win.getAnimLooping();
 
          int anim = m_model->addAnimation( mode, name.toUtf8() );
+         m_model->setAnimFrameCount( mode, anim, frameCount );
+         m_model->setAnimFPS( mode, anim, fps );
+         m_model->setAnimLooping( mode, anim, loop );
          m_model->setCurrentAnimation( mode, anim );
          m_model->operationComplete( tr( "New Animation", "operation complete" ).toUtf8() );
          initialize( m_model, true );
@@ -261,6 +277,37 @@ void AnimWidget::setCurrentFrame( int frame )
    DecalManager::getInstance()->modelUpdated( m_model );
 }
 
+void AnimWidget::editClicked()
+{
+   NewAnim win( this );
+   win.editMode();
+   win.setSkeletal( m_mode == Model::ANIMMODE_SKELETAL );
+
+   win.setAnimName( m_model->getAnimName( m_mode, m_currentAnim ) );
+   win.setAnimFrameCount( m_model->getAnimFrameCount( m_mode, m_currentAnim ) );
+   win.setAnimFPS( m_model->getAnimFPS( m_mode, m_currentAnim ) );
+   win.setAnimLooping( m_model->getAnimLooping( m_mode, m_currentAnim ) );
+
+   if ( win.exec() )
+   {
+     QString name = win.getAnimName();
+     unsigned frameCount = win.getAnimFrameCount();
+     double fps = win.getAnimFPS();
+     bool loop = win.getAnimLooping();
+
+     m_model->setAnimName( m_mode, m_currentAnim, name.toUtf8() );
+     m_model->setAnimFrameCount( m_mode, m_currentAnim, frameCount );
+     m_model->setAnimFPS( m_mode, m_currentAnim, fps );
+     m_model->setAnimLooping( m_mode, m_currentAnim, loop );
+
+     m_model->operationComplete( tr( "Edit Animation", "operation complete" ).toUtf8() );
+
+     refreshPage();
+
+     return;
+  }
+}
+
 void AnimWidget::deleteClicked()
 {
    int index = m_animName->currentIndex();
@@ -302,22 +349,8 @@ void AnimWidget::changeFPS()
    }
 }
 
-void AnimWidget::changeFrameCountFocusIn()
-{
-   m_changeFrameFocused = true;
-
-   // Loose focus when clicking outside of frame count widget.
-   setFocusPolicy( Qt::ClickFocus );
-}
-
 void AnimWidget::changeFrameCount()
 {
-   if ( m_changeFrameFocused )
-   {
-      m_changeFrameDeferred = true;
-      return;
-   }
-
    if ( !m_ignoreChange )
    {
       if ( m_animCount > 0 )
@@ -335,21 +368,6 @@ void AnimWidget::changeFrameCount()
    }
 }
 
-void AnimWidget::changeFrameCountFocusOut()
-{
-   if ( m_changeFrameFocused )
-   {
-      m_changeFrameFocused = false;
-      setFocusPolicy( Qt::NoFocus );
-
-      if ( m_changeFrameDeferred )
-      {
-         m_changeFrameDeferred = true;
-         changeFrameCount();
-      }
-   }
-}
-
 void AnimWidget::clearFrame()
 {
    Model::AnimationModeE mode = m_model->getAnimationMode();
@@ -721,6 +739,7 @@ void AnimWidget::refreshPage()
          Model::AnimationModeE mode = indexToMode( index );
          index = indexToAnim( index );
 
+         m_editButton->setEnabled( true );
          m_deleteButton->setEnabled( true );
          if ( m_playing )
          {
@@ -757,6 +776,7 @@ void AnimWidget::refreshPage()
       }
       else
       {
+         m_editButton->setEnabled( false );
          m_deleteButton->setEnabled( false );
          m_frameCount->setEnabled( false );
          m_fps->setEnabled( false );
