@@ -55,12 +55,11 @@ class AnimWidget : public QWidget, public Ui::AnimWidgetBase
 
    public slots:
       void nameSelected(int);
+      void editClicked();
       void deleteClicked();
       void setCurrentFrame(int);
       void changeFPS();
       void changeFrameCount();
-      void changeFrameCountFocusIn();
-      void changeFrameCountFocusOut();
 
       void timeElapsed();
 
@@ -138,9 +137,6 @@ class AnimWidget : public QWidget, public Ui::AnimWidgetBase
       FramePointCopyList    m_framePointCopyList;
 
       QTimer * m_animTimer;
-
-      bool m_changeFrameFocused;
-      bool m_changeFrameDeferred;
 };
 
 #endif // __ANIMWIDGET_H
