@@ -1,4 +1,4 @@
-/*  Misfit Model 3D
+/*  Maverick Model 3D
  * 
  *  Copyright (c) 2004-2007 Kevin Worcester
  * 
@@ -25,7 +25,7 @@
 #define __HELPWIN_H
 
 #include "helpwin.base.h"
-#include <QtGui/QDialog>
+#include <QtWidgets/QDialog>
 
 class HelpWin : public QDialog, public Ui::HelpWinBase
 {
