@@ -1,4 +1,4 @@
-/*  Misfit Model 3D
+/*  Maverick Model 3D
  * 
  *  Copyright (c) 2004-2007 Kevin Worcester
  * 
@@ -23,7 +23,7 @@
 
 #include "mapdirection.h"
 
-#include <QtGui/QComboBox>
+#include <QtWidgets/QComboBox>
 
 MapDirection::MapDirection( QWidget * parent )
    : QDialog( parent )
