@@ -38,8 +38,7 @@ ModelView::ModelView( Toolbox * toolbox, QWidget * parent )
 {
    setupUi( this );
 
-   QString zoomStr;
-   zoomStr.sprintf( "%f", m_modelView->getZoomLevel() );
+   QString zoomStr = QString::asprintf( "%f", m_modelView->getZoomLevel() );
    m_zoomInput->setText( zoomStr );
 
    connect( m_modelView, SIGNAL(viewDirectionChanged(int)), this, SLOT(setViewDirection(int)));
@@ -127,8 +126,8 @@ void ModelView::updateCaptureGL()
    m_modelView->updateCaptureGL();
 }
 
-QImage ModelView::grabFrameBuffer( bool withAlpha )
+QImage ModelView::grabFramebuffer()
 {
-   return m_modelView->grabFrameBuffer( withAlpha );
+   return m_modelView->grabFramebuffer();
 }
 
