@@ -56,8 +56,10 @@ class ModelApp : public QApplication
 {
 public:
    ModelApp(int &argc, char **argv)
-       : QApplication(argc, argv)
+       : QApplication(argc, argv),
+         m_darkMode(false)
    {
+      checkDarkMode();
    }
 
    bool event(QEvent *event)
@@ -67,9 +69,26 @@ public:
 
          ViewWindow::openModelInEmptyWindow( openEvent->file().toUtf8() );
       }
+      else if ( event->type() == QEvent::ApplicationPaletteChange )
+      {
+         checkDarkMode();
+      }
 
       return QApplication::event(event);
    }
+
+   void checkDarkMode()
+   {
+      m_darkMode = this->palette().window().color().value() < this->palette().windowText().color().value();
+   }
+
+   bool getDarkMode()
+   {
+      return m_darkMode;
+   }
+
+   protected:
+      bool m_darkMode;
 };
 
 static ModelApp     * s_app = NULL;
@@ -110,8 +129,22 @@ QApplication * ui_getapp()
    return s_app;
 }
 
+bool ui_getdarkmode()
+{
+   return ( s_app && s_app->getDarkMode() );
+}
+
 int ui_prep( int & argc, char * argv[] )
 {
+#if defined Q_OS_UNIX && !defined Q_OS_MAC
+   // Don't use Wayland unless requested (QT_QPA_PLATFORM=wayland)
+   char *platform = getenv( "QT_QPA_PLATFORM" );
+   if ( !platform || !*platform )
+   {
+      setenv( "QT_QPA_PLATFORM", "xcb", 1 );
+   }
+#endif
+
    // Don't use OpenGL ES (ANGLE, software) on Windows
    // (It must be set before QApplication is created)
    QCoreApplication::setAttribute( Qt::AA_UseDesktopOpenGL );
