@@ -1,4 +1,4 @@
-/*  Misfit Model 3D
+/*  Maverick Model 3D
  * 
  *  Copyright (c) 2004-2007 Kevin Worcester
  * 
@@ -31,8 +31,8 @@
 #include "modelviewport.h"
 #include "3dmprefs.h"
 
-#include <QtGui/QLayout>
-#include <QtGui/QGridLayout>
+#include <QtWidgets/QLayout>
+#include <QtWidgets/QGridLayout>
 
 ViewPanel::ViewPanel( Toolbox * toolbox, QWidget * parent )
    : QWidget( parent ),
@@ -80,6 +80,12 @@ void ViewPanel::freeTextures()
 
 void ViewPanel::setModel( Model * model )
 {
+   if ( m_model != NULL && model != NULL )
+   {
+      model->setPerspectiveDrawMode(m_model->getPerspectiveDrawMode());
+      model->setCanvasDrawMode(m_model->getCanvasDrawMode());
+   }
+
    for ( unsigned t = 0; t < m_viewCount; t++ )
    {
       m_modelView[t]->setModel( model );
@@ -105,42 +111,32 @@ void ViewPanel::frameArea( double x1, double y1, double z1, double x2, double y2
 
 void ViewPanel::wireframeEvent()
 {
-   for ( unsigned i = 0; i < m_viewCount; i++ )
-   {
-      m_modelView[i]->wireframeEvent();
-   }
+   m_model->setPerspectiveDrawMode( ModelViewport::ViewWireframe );
+   modelUpdatedEvent();
 }
 
 void ViewPanel::flatEvent()
 {
-   for ( unsigned i = 0; i < m_viewCount; i++ )
-   {
-      m_modelView[i]->flatEvent();
-   }
+   m_model->setPerspectiveDrawMode( ModelViewport::ViewFlat );
+   modelUpdatedEvent();
 }
 
 void ViewPanel::smoothEvent()
 {
-   for ( unsigned i = 0; i < m_viewCount; i++ )
-   {
-      m_modelView[i]->smoothEvent();
-   }
+   m_model->setPerspectiveDrawMode( ModelViewport::ViewSmooth );
+   modelUpdatedEvent();
 }
 
 void ViewPanel::textureEvent()
 {
-   for ( unsigned i = 0; i < m_viewCount; i++ )
-   {
-      m_modelView[i]->textureEvent();
-   }
+   m_model->setPerspectiveDrawMode( ModelViewport::ViewTexture );
+   modelUpdatedEvent();
 }
 
 void ViewPanel::alphaEvent()
 {
-   for ( unsigned i = 0; i < m_viewCount; i++ )
-   {
-      m_modelView[i]->alphaEvent();
-   }
+   m_model->setPerspectiveDrawMode( ModelViewport::ViewAlpha );
+   modelUpdatedEvent();
 }
 
 void ViewPanel::canvasWireframeEvent()
