@@ -69,8 +69,8 @@ static unsigned bestNormal( double * n )
    float norm[3];
 
    norm[0] = n[0];
-   norm[1] = n[2];
-   norm[2] = n[1];
+   norm[1] = n[1];
+   norm[2] = n[2];
 
    for ( unsigned t = 0; t < MAX_QUAKE_NORMALS; t++ )
    {
@@ -346,7 +346,7 @@ Model::ModelErrorE Md2Filter::readFile( Model * model, const char * const filena
          {
             string md2path = tempStr;
             size_t slashChar = md2path.rfind( '/' );
-            log_debug( "The '/' char is at %d\n", slashChar );
+            log_debug( "The '/' char is at %" PORTuSIZE "\n", slashChar );
             if ( slashChar < md2path.size() )
             {
                md2path.resize( slashChar + 1 );
