@@ -2682,7 +2682,7 @@ Model::ModelErrorE MisfitFilter::writeFile( Model * model, const char * const fi
 
             char * filedup = strdup( fileStr.c_str() );
             replaceSlash( filedup );
-            utf8chrtrunc( filedup, fileStr.size()-1 );
+            utf8chrtrunc( filedup, fileStr.size() );
 
             m_dst->write( backSize );
             m_dst->write( cb.flags );
