@@ -26,7 +26,7 @@
 
 #ifdef MM3D_EDIT
 
-void Model::insertVertex( unsigned index, Model::Vertex * vertex )
+void Model::insertVertex( unsigned index, Model::Vertex * vertex, vector<Model::FrameAnimVertex *> * vertexAnimFrames )
 {
    if ( m_animationMode )
    {
@@ -37,9 +37,47 @@ void Model::insertVertex( unsigned index, Model::Vertex * vertex )
 
    invalidateNormals();
 
+   vector<Model::FrameAnimVertex *>::iterator fav;
+   if ( vertexAnimFrames )
+   {
+      fav = vertexAnimFrames->begin();
+   }
+
    if ( index == m_vertices.size() )
    {
       m_vertices.push_back( vertex );
+
+      vector<FrameAnim *>::iterator ait;
+      for ( ait = m_frameAnims.begin(); ait != m_frameAnims.end(); ait++ )
+      {
+         FrameAnimDataList::iterator fit;
+         int frameNum = 0;
+         for ( fit = (*ait)->m_frameData.begin(); fit != (*ait)->m_frameData.end(); fit++, frameNum++ )
+         {
+            FrameAnimVertex * add;
+
+            if ( vertexAnimFrames )
+            {
+               add = *fav;
+               fav++;
+               if ( fav == vertexAnimFrames->end() )
+               {
+                  vertexAnimFrames = NULL;
+               }
+            }
+            else
+            {
+               add = FrameAnimVertex::get();
+               for ( unsigned v = 0; v < 3; v++ )
+               {
+                  add->m_coord[v] = vertex->m_coord[v];
+                  add->m_normal[v] = 0;
+               }
+            }
+
+            (*fit)->m_frameVertices->push_back( add );
+         }
+      }
    }
    else if ( index < m_vertices.size() )
    {
@@ -55,6 +93,47 @@ void Model::insertVertex( unsigned index, Model::Vertex * vertex )
          }
          count++;
       }
+
+      vector<FrameAnim *>::iterator ait;
+      for ( ait = m_frameAnims.begin(); ait != m_frameAnims.end(); ait++ )
+      {
+         FrameAnimDataList::iterator fit;
+         int frameNum = 0;
+         for ( fit = (*ait)->m_frameData.begin(); fit != (*ait)->m_frameData.end(); fit++, frameNum++ )
+         {
+            FrameAnimVertexList::iterator pit;
+            for ( count = 0, pit = (*fit)->m_frameVertices->begin(); pit != (*fit)->m_frameVertices->end(); pit++ )
+            {
+               if ( count == index )
+               {
+                  FrameAnimVertex * add;
+
+                  if ( vertexAnimFrames )
+                  {
+                     add = *fav;
+                     fav++;
+                     if ( fav == vertexAnimFrames->end() )
+                     {
+                        vertexAnimFrames = NULL;
+                     }
+                  }
+                  else
+                  {
+                     add = FrameAnimVertex::get();
+                     for ( unsigned v = 0; v < 3; v++ )
+                     {
+                        add->m_coord[v] = vertex->m_coord[v];
+                        add->m_normal[v] = 0;
+                     }
+                  }
+
+                  (*fit)->m_frameVertices->insert( pit, add );
+                  break;
+               }
+               count++;
+            }
+         }
+      }
    }
    else
    {
@@ -75,9 +154,9 @@ void Model::removeVertex( unsigned index )
 
    if ( index < m_vertices.size() )
    {
-      unsigned count = 0;
+      unsigned count;
       vector<Vertex *>::iterator it;
-      for ( it = m_vertices.begin(); it != m_vertices.end(); it++ )
+      for ( count = 0, it = m_vertices.begin(); it != m_vertices.end(); it++ )
       {
          if ( count == index )
          {
@@ -87,6 +166,25 @@ void Model::removeVertex( unsigned index )
          }
          count++;
       }
+
+      vector<FrameAnim *>::iterator ait;
+      for ( ait = m_frameAnims.begin(); ait != m_frameAnims.end(); ait++ )
+      {
+         FrameAnimDataList::iterator fit;
+         for ( fit = (*ait)->m_frameData.begin(); fit != (*ait)->m_frameData.end(); fit++ )
+         {
+            FrameAnimVertexList::iterator vit;
+            for ( count = 0, vit = (*fit)->m_frameVertices->begin(); vit != (*fit)->m_frameVertices->end(); vit++ )
+            {
+               if ( count == index )
+               {
+                  (*fit)->m_frameVertices->erase( vit );
+                  break;
+               }
+               count++;
+            }
+         }
+      }
    }
    else
    {
@@ -544,7 +642,7 @@ void Model::removeInfluence( const Position & pos, unsigned index )
    }
 }
 
-void Model::insertPoint( unsigned index, Model::Point * point )
+void Model::insertPoint( unsigned index, Model::Point * point, vector<Model::FrameAnimPoint *> * pointAnimFrames )
 {
    if ( m_animationMode )
    {
@@ -553,9 +651,46 @@ void Model::insertPoint( unsigned index, Model::Point * point )
 
    m_changeBits |= AddOther;
 
+   vector<Model::FrameAnimPoint *>::iterator fap;
+   if ( pointAnimFrames )
+   {
+      fap = pointAnimFrames->begin();
+   }
+
    if ( index == m_points.size() )
    {
       m_points.push_back( point );
+
+      vector<FrameAnim *>::iterator ait;
+      for ( ait = m_frameAnims.begin(); ait != m_frameAnims.end(); ait++ )
+      {
+         FrameAnimDataList::iterator fit;
+         for ( fit = (*ait)->m_frameData.begin(); fit != (*ait)->m_frameData.end(); fit++ )
+         {
+            FrameAnimPoint * add;
+
+            if ( pointAnimFrames )
+            {
+               add = *fap;
+               fap++;
+               if ( fap == pointAnimFrames->end() )
+               {
+                  pointAnimFrames = NULL;
+               }
+            }
+            else
+            {
+               add = FrameAnimPoint::get();
+               for ( unsigned v = 0; v < 3; v++ )
+               {
+                  add->m_trans[v] = point->m_trans[v];
+                  add->m_rot[v] = point->m_rot[v];
+               }
+            }
+
+            (*fit)->m_framePoints->push_back( add );
+         }
+      }
    }
    else if ( index < m_points.size() )
    {
@@ -570,6 +705,46 @@ void Model::insertPoint( unsigned index, Model::Point * point )
          }
          count++;
       }
+
+      vector<FrameAnim *>::iterator ait;
+      for ( ait = m_frameAnims.begin(); ait != m_frameAnims.end(); ait++ )
+      {
+         FrameAnimDataList::iterator fit;
+         for ( fit = (*ait)->m_frameData.begin(); fit != (*ait)->m_frameData.end(); fit++ )
+         {
+            FrameAnimPointList::iterator pit;
+            for ( count = 0, pit = (*fit)->m_framePoints->begin(); pit != (*fit)->m_framePoints->end(); pit++ )
+            {
+               if ( count == index )
+               {
+                  FrameAnimPoint * add;
+
+                  if ( pointAnimFrames )
+                  {
+                     add = *fap;
+                     fap++;
+                     if ( fap == pointAnimFrames->end() )
+                     {
+                        pointAnimFrames = NULL;
+                     }
+                  }
+                  else
+                  {
+                     add = FrameAnimPoint::get();
+                     for ( unsigned v = 0; v < 3; v++ )
+                     {
+                        add->m_trans[v] = point->m_trans[v];
+                        add->m_rot[v] = point->m_rot[v];
+                     }
+                  }
+
+                  (*fit)->m_framePoints->insert( pit, add );
+                  break;
+               }
+               count++;
+            }
+         }
+      }
    }
    else
    {
@@ -601,6 +776,25 @@ void Model::removePoint( unsigned point )
          }
          count++;
       }
+
+      vector<FrameAnim *>::iterator ait;
+      for ( ait = m_frameAnims.begin(); ait != m_frameAnims.end(); ait++ )
+      {
+         FrameAnimDataList::iterator fit;
+         for ( fit = (*ait)->m_frameData.begin(); fit != (*ait)->m_frameData.end(); fit++ )
+         {
+            FrameAnimPointList::iterator pit;
+            for ( count = 0, pit = (*fit)->m_framePoints->begin(); pit != (*fit)->m_framePoints->end(); pit++ )
+            {
+               if ( count == point )
+               {
+                  (*fit)->m_framePoints->erase( pit );
+                  break;
+               }
+               count++;
+            }
+         }
+      }
    }
    else
    {
