@@ -622,13 +622,14 @@ class MU_DeleteVertex : public ModelUndo
 
       unsigned size();
 
-      void deleteVertex( unsigned vertexNum, Model::Vertex * vertex );
+      void deleteVertex( unsigned vertexNum, Model::Vertex * vertex, vector<Model::FrameAnimVertex *> * vertexAnimFrames );
 
    private:
       typedef struct _DeleteVertex_t
       {
          unsigned vertexNum;
          Model::Vertex * vertex;
+         vector<Model::FrameAnimVertex *> * vertexAnimFrames;
       } DeleteVertexT;
       typedef list<DeleteVertexT> DeleteVertexList;
 
@@ -670,11 +671,12 @@ class MU_DeletePoint : public ModelUndo
 
       unsigned size();
 
-      void deletePoint( unsigned pointNum, Model::Point * point );
+      void deletePoint( unsigned pointNum, Model::Point * point, vector<Model::FrameAnimPoint *> * pointAnimFrames );
 
    private:
       unsigned       m_pointNum;
       Model::Point * m_point;
+      vector<Model::FrameAnimPoint *> * m_pointAnimFrames;
 };
 
 class MU_DeleteProjection : public ModelUndo
