@@ -1,4 +1,4 @@
-/*  Misfit Model 3D
+/*  Maverick Model 3D
  * 
  *  Copyright (c) 2004-2007 Kevin Worcester
  * 
@@ -55,7 +55,7 @@ template <typename T> void sorted_list<T>::insert_sorted( const T & val )
    unsigned len = this->size();
    if ( len == 0 || (*this)[len-1] < val )
    {
-      push_back( val );
+      this->push_back( val );
    }
    else
    {
@@ -128,7 +128,7 @@ template <typename T> void sorted_ptr_list<T>::insert_sorted( const T & val )
    unsigned len = this->size();
    if ( len == 0 || *((*this)[len-1]) < *val )
    {
-      push_back( val );
+      this->push_back( val );
    }
    else
    {
