@@ -1,4 +1,4 @@
-/*  Misfit Model 3D
+/*  Maverick Model 3D
  * 
  *  Copyright (c) 2004-2007 Kevin Worcester
  * 
@@ -24,12 +24,12 @@
 #include "scaletoolwidget.h"
 #include "3dmprefs.h"
 
-#include <QtGui/QLayout>
-#include <QtGui/QVBoxLayout>
-#include <QtGui/QHBoxLayout>
-#include <QtGui/QGroupBox>
-#include <QtGui/QLabel>
-#include <QtGui/QComboBox>
+#include <QtWidgets/QLayout>
+#include <QtWidgets/QVBoxLayout>
+#include <QtWidgets/QHBoxLayout>
+#include <QtWidgets/QGroupBox>
+#include <QtWidgets/QLabel>
+#include <QtWidgets/QComboBox>
 
 ScaleToolWidget::ScaleToolWidget( Observer * observer, QMainWindow * parent )
    : ToolWidget ( parent ),
