@@ -1,4 +1,4 @@
-/*  Misfit Model 3D
+/*  Maverick Model 3D
  * 
  *  Copyright (c) 2008 Kevin Worcester
  * 
@@ -24,16 +24,16 @@
 #ifndef TOOLWIDGET_H_INC__
 #define TOOLWIDGET_H_INC__
 
-#include <QtGui/QDockWidget>
-#include <QtGui/QMainWindow>
-#include <QtGui/QBoxLayout>
+#include <QtWidgets/QDockWidget>
+#include <QtWidgets/QMainWindow>
+#include <QtWidgets/QBoxLayout>
 
 class ToolWidget : public QDockWidget
 {
    Q_OBJECT
 
    public:
-      ToolWidget( QMainWindow * window );
+      ToolWidget( QMainWindow * window, const QString & title = "" );
       virtual ~ToolWidget();
 
    protected:
